<%inherit file="base.mako"/>

<%block name="lo_head_title">
  <%
    site_name = config['SITEINFO']['site_name']
    if site_name:
      bookshelf_title = _("Bookshelf") + ' - ' + site_name
    else:
      bookshelf_title = _("Bookshelf") + ' - ' + _("LoNote")
  %>
  ${bookshelf_title | h}
</%block>

<%block name="lo_head_stylesheet">
  <style>
    * {
      -moz-user-select: none; 
      -khtml-user-select: none; 
      -webkit-user-select: none; 
      -o-user-select: none; 
      user-select: none;
    }
  </style>
</%block>

<%block name="lo_nav_header">
  <%
    if 'e' in a_type:
      text = _('Drag & drop to move following papers')
    else:
      text = _('Without full access permission, you cannot move following papers')
  %>
  <a id="lo-nav-title" class="navbar-brand" data-toggle="modal" tooltip data-title="${text | h}" data-placement="bottom" data-container="body" href="#lo-papermenu-modal"> ${_("Bookshelf") | h} </a>
</%block>

<%namespace file="element.mako" import="*"/>

<%block name="lo_nav_tools">
  <div class="btn-group">
    ${btn_search()}
    ${btn_configure_start()}
  </div>
</%block>

<%block name="lo_data">
  ${modal_search()}
  ${modal_configure_start()}
</%block>

<%namespace file="data-bookshelf.mako" import="*"/>

<%block name="lo_article_content">${editnav_all(bs)}</%block>

<%block name="append_script">
  <script>

    function lo_bs_checked_save(){
      var lo_bs_checked = new Array();
      $('#lo-bookshelf input:checked').each(function(){
        lo_bs_checked.push($(this).attr('id'));
      });
      localStorage['lo_bs_checked'] = JSON.stringify(lo_bs_checked);
    };
    function lo_bs_checked_restore(){
      try{
        var lo_bs_checked = JSON.parse(localStorage['lo_bs_checked']);
      }catch(e){return}
      for (x in lo_bs_checked){
        var query = '#lo-bookshelf input[id=' + lo_bs_checked[x] + ']';
        $(query).attr('checked', 'checked');
      };
    };
    $(document).ready(function(){
      lo_bs_checked_restore();
      $(window).on('beforeunload', lo_bs_checked_save);
    });

    // moving
    function lo_sortable_updatefunc( event, ui ) {
      // moved
      var moved_paper_url = ui.item.children('a:first').attr('href');
      var moved_bid = URI(moved_paper_url).segment()[1]
      var moved_pid = URI(moved_paper_url).segment()[2]
      // move_to_root ?
      var upper_level = ui.item.parent().parent();
      if (upper_level.is('li')){ var move_to_root = false; }
      else {var move_to_root = true; }

      if (move_to_root == false){ // not root
        var order = ui.item.prevAll().length + 1;
        // parent
        var parent_paper_url = upper_level
          .children('a:first')
          .attr('href');
        var parent_bid = URI(parent_paper_url).segment()[1]
        var parent_pid = URI(parent_paper_url).segment()[2]
        $.ajax({
          type: 'POST',
          url: '/func/movepaper',
          async: false,
          data: {
            'parent_bid': parent_bid,
            'parent_pid': parent_pid,
            'moved_bid': moved_bid,
            'moved_pid': moved_pid,
            'order': order
          }
        }).done(function(){
            // bid change -> reload
            if (parent_bid != moved_bid){location.reload(true)}
          });
      } else { // move_to_root!
        // record bid order
        var bids_list = []
        ui.item.parent().children('li').each(function(){
            url = $(this).find('a:first').attr('href');
            bid = URI(url).segment()[1];
            bids_list.push(bid);
          });
        // standard index in bids_list
        var index = ui.item.prevAll().length;
        var moved_ori_bid = bids_list[index];
        bids_list[index] = ''; // delete
        if (bids_list.indexOf(moved_ori_bid) == -1) { // book 順序重排
          bids_list[index] = moved_ori_bid;
          $.ajax({
            type: 'POST',
            url: '/func/book-re-order',
            async: false,
            data: {
              'bids_list': JSON.stringify(bids_list),
            }
          });
        } else { // 新 book 誕生，新 book 的位置是空白
          // input new bid
          var new_bid = prompt('Type the new book filename:', '');
          if (new_bid == null){
            location.reload();
          }else{
            $.ajax({
              type: 'POST',
              url: '/func/book-export-ready',
              async: false,
              data: {
                'moved_bid': moved_bid,
                'moved_pid': moved_pid,
                'bids_list': JSON.stringify(bids_list),
                'new_bid': new_bid
              }
            })
              .fail(function(jqXHR, textStatus, errorThrown){
                alert( jqXHR.responseText );
              })
              .always(function(){ location.reload(true); })
          }
        }
      }
    }

    // disable tooltip

    % if 'e' in a_type:

      $(document).ready(function(){
        $('.sortable').nestedSortable({
          handle: 'a',
          items: 'li',
          toleranceElement: '> a',
          listType: 'ul',
          // protectRoot: true,
          placeholder: 'placeholder',
          forcePlaceholderSize: true,
          delay: 0,
          tolerance: "pointer",
          cursor: "move",
          // revert: 250,
          opacity: 0.6,
          helper: function(event, item) {
            return item.clone().css({'outline': '1px solid #4183C4', 'background-color': '#fff'});
          },
          update: lo_sortable_updatefunc
        });
      });

    % endif

  </script>
</%block>
